aboutsummaryrefslogtreecommitdiff
path: root/portal-gui/scripts/list_resources.py
diff options
context:
space:
mode:
Diffstat (limited to 'portal-gui/scripts/list_resources.py')
-rwxr-xr-xportal-gui/scripts/list_resources.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/portal-gui/scripts/list_resources.py b/portal-gui/scripts/list_resources.py
index 180a9202..f7abf3d2 100755
--- a/portal-gui/scripts/list_resources.py
+++ b/portal-gui/scripts/list_resources.py
@@ -20,7 +20,7 @@
# portal-gui's sqlite database. It asks rpkid for the list of received
# resources, and the handles of any children.
#
# This script should be run in the directory containing the myrpki.conf
# for the handle that is self-hosting rpkid.
#
# Exit values:
@@ -50,9 +50,9 @@ verbose = False
version = '$Id$'
def query_rpkid():
"""Fetch our received resources from the local rpkid using the myrpki.conf
in the current directory."""
- cfg_file = os.getenv("MYRPKI_CONF", "myrpki.conf")
+ cfg_file = os.getenv("RPKI_CONF", "rpki.conf")
cfg = rpki.config.parser(cfg_file, "myrpki")
bpki_servers = CA(cfg_file, cfg.get("bpki_servers_directory"))
rpkid_base = "http://%s:%s/" % (cfg.get("rpkid_server_host"), cfg.get("rpkid_server_port"))
@@ -20,7 +20,7 @@
# resources, and the handles of any children.
#
-# This script should be run in the directory containing the myrpki.conf
+# This script should be run in the directory containing the rpki.conf
# for the handle that is self-hosting rpkid.
#
@@ -50,9 +50,9 @@ verbose = False
version = '$Id$'
def query_rpkid():
- """Fetch our received resources from the local rpkid using the myrpki.conf
+ """Fetch our received resources from the local rpkid using the rpki.conf
in the current directory."""